# BitRot Library
A Python library for simulating digital image decay.

## Installation
`pip install bitrot-decay`

## Usage
```python
import bitrot
bitrot.decay_file("input.jpg", "output.jpg", integrity=0.5)